===============================
Yarely
===============================


.. image:: https://img.shields.io/pypi/v/yarely.svg
        :target: https://pypi.python.org/pypi/yarely

Yarely is a modular, extensible digital signage player currently designed to run only on macOS. The player supports a wide range of content types (e.g. images, videos and web content) that are displayed according to a schedule and set of constraints specified by the user. The player also supports external triggering of content through web sockets to enable applications such as display personalisation.

* GitHub repo: https://github.com/opendisplays/yarely/
* Documentation: https://yarely.readthedocs.io.
* Free software: Apache Software License 2.0

Details of design and implementation of Yarely and associated components can be found in the following publications:

* `Yarely: a software player for open pervasive display networks <http://doi.org/10.1145/2491568.2491575>`_
* `Are You Feeling Lucky?: Lottery-based Scheduling for Public Displays <http://doi.org/10.1145/2757710.2757721>`_
* `Supporting user appropriation of public displays <http://eprints.lancs.ac.uk/70431/>`_

Build Status
-------------

Mac OS X (>=10.6):

.. image:: https://img.shields.io/travis/seclinch/yarely.svg
        :target: https://travis-ci.org/opendisplays/yarely

Dependancies
-------------

.. image:: https://pyup.io/repos/github/seclinch/yarely/shield.svg
     :target: https://pyup.io/repos/github/opendisplays/yarely/
     :alt: Updates
